import typing

import QuantConnect.Lean.Launcher
import System


class Program(System.Object):
    """This class has no documentation."""

    @staticmethod
    def Main(args: typing.List[str]) -> None:
        ...


